Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'spec/spec_helper.rb')
-rw-r--r--spec/spec_helper.rb5
1 files changed, 3 insertions, 2 deletions
diff --git a/spec/spec_helper.rb b/spec/spec_helper.rb
index 34f9d189d71..2cc3e515d1d 100644
--- a/spec/spec_helper.rb
+++ b/spec/spec_helper.rb
@@ -269,9 +269,10 @@ RSpec.configure do |config|
stub_feature_flags(unified_diff_components: false)
# The following `vue_issues_list` stub can be removed once the
# Vue issues page has feature parity with the current Haml page
stub_feature_flags(vue_issues_list: false)
+ stub_feature_flags(vue_issuables_list: false)
# Disable `refactor_blob_viewer` as we refactor
# the blob viewer. See the follwing epic for more:
@@ -269,9 +269,10 @@ RSpec.configure do |config|
stub_feature_flags(unified_diff_components: false)
- # The following `vue_issues_list` stub can be removed once the
- # Vue issues page has feature parity with the current Haml page
+ # The following `vue_issues_list`/`vue_issuables_list` stubs can be removed
+ # once the Vue issues page has feature parity with the current Haml page
stub_feature_flags(vue_issues_list: false)